pub fn with_value_decode_depth_limit<T>(
max_depth: Option<usize>,
decode: impl FnOnce() -> T,
) -> TExpand description
Runs decode with the requested container-depth limit for Value decoding on this thread.
This is used by version-aware protocol decoders so historical versions can retain their original behavior while current versions reject excessive nesting before constructing a recursive value tree.